pub struct StagedFile { /* private fields */ }Expand description
Creates a temporary file which can then be committed to a final path.
Implementations
Sourceimpl StagedFile
impl StagedFile
Sourcepub fn with_final_path<P>(final_path: P) -> Result<Self, Error>
pub fn with_final_path<P>(final_path: P) -> Result<Self, Error>
Instantiates a new staged file with the desired final path.
The desired final path is where the file contents should be if the staged file is committed.
A temporary directory and file are created during this function call.
Important
If a file exists at the desired final file path, it will be overwritten.
Errors
If the final path is invalid (e.g. is a directory) or if the final path’s
parent directory cannot be determined, an Error will be returned.
Any I/O error which occurs when creating the temporary directory or file will also be returned.
Sourcepub fn with_final_path_and_temp_dir_prefix<P>(
final_path: P,
temp_dir_prefix: Option<&str>,
) -> Result<Self, Error>
pub fn with_final_path_and_temp_dir_prefix<P>( final_path: P, temp_dir_prefix: Option<&str>, ) -> Result<Self, Error>
Instantiates a new staged file with the desired final path and a temporary directory prefix.
The desired final path is where the file contents should be if the staged file is committed.
A temporary directory and file are created during this function call. The temporary directory will have the prefix given or a default prefix will be chosen.
Important
If a file exists at the desired final file path, it will be overwritten.
Errors
If the final path is invalid (e.g. is a directory) or if the final path’s
parent directory cannot be determined, an Error will be returned.
Any I/O error which occurs when creating the temporary directory or file will also be returned.
Sourcepub fn commit(self) -> Result<(), Error>
pub fn commit(self) -> Result<(), Error>
Commits the temporary file contents into the desired final path.
If the contents should not be committed, then allow the StagedFile to
be dropped without calling commit.
Important
If a file exists at the desired final file path, it will be overwritten.
Errors
Any I/O errors encountered will be returned.